package
Version:
v1.0.0
Opens a new window with list of versions in this module.
Published: Jul 21, 2022
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type UpsertUserLoginSpec struct {
Email string `validate:"required,email"`
Password string `validate:"required"`
}
type UpsertUserSpec struct {
UserID int `validate:"required"`
Email string `validate:"required,email"`
Password string `validate:"required"`
Role string `validate:"required"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.